@@ -3,9 +3,9 @@ package Syntax::Keyword::Junction::One;
 use strict;
 use warnings;
 
-our $VERSION = '0.003006'; # VERSION
+our $VERSION = '0.003008'; # VERSION
 
-use base 'Syntax::Keyword::Junction::Base';
+use parent 'Syntax::Keyword::Junction::Base';
 
 BEGIN {
   if ($] >= 5.010001) {
@@ -287,13 +287,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Syntax::Keyword::Junction::One
 
 =head1 VERSION
 
-version 0.003006
+version 0.003008
 
 =head1 AUTHORS
 
@@ -311,7 +313,7 @@ Carl Franks
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
